==> beast-sales-order-api-2.3.7-20230719.045134-27-sources.jar: com/thebeastshop/salesorder/dto/SoOrderCond.java <==
package com.thebeastshop.salesorder.dto;


import com.thebeastshop.common.BaseQueryCond;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.List;

public class SoOrderCond extends BaseQueryCond {

	// constructor
	public SoOrderCond() {

	}

	// original
	private long id;

	private String code;

	private String outerOrderCode;
	
	private String sourceSoCode;

	private Integer salesOrderType;

	private List<Integer> salesOrderTypeList;

	private Integer salesOrderStatus;

	private List<Integer> salesOrderStatusList;

	private String channelCode;

	private String dispatchChannelCode;

	private String dispatchWarehouseCode;

	private String memberCode;

	private Long createOperatorId;

	private Integer isForceAudit;

	private Integer isDownload;

	private List<Integer> paymentTypeList;

	private BigDecimal needToPayAmount;

	// self
	private List<Long> idList;

	private long userId;

	private String createTimeBegin;

	private String createTimeEnd;

	private String createTimeBeginHHmmss;

	private String createTimeEndHHmmss;

	private String payTimeBegin;

	private String payTimeEnd;

	private String payTimeBeginHHmmss;

	private String payTimeEndHHmmss;

	private String cancelTimeBegin;

	private String cancelTimeEnd;

	private String cancelTimeBeginHHmmss;

	private String cancelTimeEndHHmmss;
	private String isProduct;
	private String sku;

	private List<String> skuList;

	private List<String> skuListNotIn;

	private String skuListStr;

	private String skuListNotInStr;

	private String expressType;//快递类型

	private List<String> expressTypeList;//快递类型

	private String expressTypeListStr;//快递类型

	private long provinceId;//包裹配送省份

	private List<Long> provinceIdList; //包裹配送省份列表

	private List<Long> cityIdList; // 包裹配送城市列表

	private String address;//包裹配送详细地址

	private Integer packageStatus;//包裹状态

	private List<Long> districtIdList;//包裹配送区县

	private List<String> channelCodeList;//渠道列表

	private String channelCodeListStr;

	private Integer crossBorderFlag;
	
	private List<Long> soIdListNot;				// 屏蔽的订单id

	/**
	 * 订单人
	 */
	private String memberName;

	/**
	 * 订单人电话
	 */
	private String memberPhone;

	/**
	 * 期望送达日期
	 */
	private String expectReceiveDateBegin;

	private String expectReceiveDateEnd;

	/**
	 * 计划发货日期
	 */
	private String planedDeliveryDateBegin;

	private String planedDeliveryDateEnd;

	/**
	 * 收货人
	 */
	private String receiver;

	/**
	 * 收货人电话
	 */
	private String receiverPhone;

	/**
	 * 快递单号
	 */
	private String deliveryCode;

	/**
	 * 排序
	 */
	private String orderBy;

	/**
	 * 集团合同
	 */
	private String groupContractCode;
    private String createOperatorName;
    
    private String buyerNick;

	private Float minAmount;

	private Float maxAmount;

    private String gatheringCode;			// 收款单号
    private Integer gatheringStatus;		// 收款状态
    private String invoiceNumber;			// 发票号
    private String physicalWarehouseCode; 	// 仓库代码
    private Integer skuStatus; 				// 商品状态

    private Integer mktGiftReceiveType; //领用单类型

	public BigDecimal getNeedToPayAmount() {
		return needToPayAmount;
	}

	public void setNeedToPayAmount(BigDecimal needToPayAmount) {
		this.needToPayAmount = needToPayAmount;
	}

	public Float getMinAmount() {
		return minAmount;
	}

	public void setMinAmount(Float minAmount) {
		this.minAmount = minAmount;
	}

	public Float getMaxAmount() {
		return maxAmount;
	}

	public void setMaxAmount(Float maxAmount) {
		this.maxAmount = maxAmount;
	}

	public String getBuyerNick() {
		return buyerNick;
	}

	public void setBuyerNick(String buyerNick) {
		this.buyerNick = buyerNick;
	}

	public Integer getCrossBorderFlag() {
		return crossBorderFlag;
	}

	public void setCrossBorderFlag(Integer crossBorderFlag) {
		this.crossBorderFlag = crossBorderFlag;
	}
    public String getCreateOperatorName() {
        return createOperatorName;
    }

    public void setCreateOperatorName(String createOperatorName) {
        this.createOperatorName = createOperatorName;
    }

	public String getIsProduct() {
		return isProduct;
	}

	public void setIsProduct(String isProduct) {
		this.isProduct = isProduct;
	}

	public String getGroupContractCode() {
		return groupContractCode;
	}

	public void setGroupContractCode(String groupContractCode) {
		this.groupContractCode = groupContractCode;
	}

	public String getOrderBy() {
		return orderBy;
	}

	public void setOrderBy(String orderBy) {
		this.orderBy = orderBy;
	}

	public long getId() {
		return id;
	}

	public void setId(long id) {
		this.id = id;
	}

	public String getCode() {
		return code;
	}

	public void setCode(String code) {
		this.code = code;
	}

	public String getOuterOrderCode() {
		return outerOrderCode;
	}

	public void setOuterOrderCode(String outerOrderCode) {
		this.outerOrderCode = outerOrderCode;
	}

	public String getSourceSoCode() {
		return sourceSoCode;
	}
	public void setSourceSoCode(String sourceSoCode) {
		this.sourceSoCode = sourceSoCode;
	}

	public Integer getSalesOrderType() {
		return salesOrderType;
	}

	public void setSalesOrderType(Integer salesOrderType) {
		this.salesOrderType = salesOrderType;
	}

	public Integer getSalesOrderStatus() {
		return salesOrderStatus;
	}

	public void setSalesOrderStatus(Integer salesOrderStatus) {
		this.salesOrderStatus = salesOrderStatus;
	}

	public List<Integer> getSalesOrderStatusList() {
		return salesOrderStatusList;
	}

	public void setSalesOrderStatusList(List<Integer> salesOrderStatusList) {
		this.salesOrderStatusList = salesOrderStatusList;
	}

	public String getChannelCode() {
		return channelCode;
	}

	public void setChannelCode(String channelCode) {
		this.channelCode = channelCode;
	}

	public String getDispatchChannelCode() {
		return dispatchChannelCode;
	}

	public void setDispatchChannelCode(String dispatchChannelCode) {
		this.dispatchChannelCode = dispatchChannelCode;
	}

	public String getDispatchWarehouseCode() {
		return dispatchWarehouseCode;
	}

	public void setDispatchWarehouseCode(String dispatchWarehouseCode) {
		this.dispatchWarehouseCode = dispatchWarehouseCode;
	}

	public String getMemberCode() {
		return memberCode;
	}

	public void setMemberCode(String memberCode) {
		this.memberCode = memberCode;
	}

	public Long getCreateOperatorId() {
		return createOperatorId;
	}

	public void setCreateOperatorId(Long createOperatorId) {
		this.createOperatorId = createOperatorId;
	}

	public Integer getIsForceAudit() {
		return isForceAudit;
	}

	public void setIsForceAudit(Integer isForceAudit) {
		this.isForceAudit = isForceAudit;
	}

	public Integer getIsDownload() {
		return isDownload;
	}

	public void setIsDownload(Integer isDownload) {
		this.isDownload = isDownload;
	}

	public long getUserId() {
		return userId;
	}

	public void setUserId(long userId) {
		this.userId = userId;
	}

	public String getCreateTimeBegin() {
		return createTimeBegin;
	}

	public void setCreateTimeBegin(String createTimeBegin) {
		this.createTimeBegin = createTimeBegin;
	}

	public String getCreateTimeEnd() {
		return createTimeEnd;
	}

	public void setCreateTimeEnd(String createTimeEnd) {
		this.createTimeEnd = createTimeEnd;
	}

	public String getCreateTimeBeginHHmmss() {
		return createTimeBeginHHmmss;
	}

	public void setCreateTimeBeginHHmmss(String createTimeBeginHHmmss) {
		this.createTimeBeginHHmmss = createTimeBeginHHmmss;
	}

	public String getCreateTimeEndHHmmss() {
		return createTimeEndHHmmss;
	}

	public void setCreateTimeEndHHmmss(String createTimeEndHHmmss) {
		this.createTimeEndHHmmss = createTimeEndHHmmss;
	}

	public String getPayTimeBegin() {
		return payTimeBegin;
	}

	public void setPayTimeBegin(String payTimeBegin) {
		this.payTimeBegin = payTimeBegin;
	}

	public String getPayTimeEnd() {
		return payTimeEnd;
	}

	public void setPayTimeEnd(String payTimeEnd) {
		this.payTimeEnd = payTimeEnd;
	}

	public String getPayTimeBeginHHmmss() {
		return payTimeBeginHHmmss;
	}

	public void setPayTimeBeginHHmmss(String payTimeBeginHHmmss) {
		this.payTimeBeginHHmmss = payTimeBeginHHmmss;
	}

	public String getPayTimeEndHHmmss() {
		return payTimeEndHHmmss;
	}

	public void setPayTimeEndHHmmss(String payTimeEndHHmmss) {
		this.payTimeEndHHmmss = payTimeEndHHmmss;
	}

	public String getCancelTimeBegin() {
		return cancelTimeBegin;
	}

	public void setCancelTimeBegin(String cancelTimeBegin) {
		this.cancelTimeBegin = cancelTimeBegin;
	}

	public String getCancelTimeEnd() {
		return cancelTimeEnd;
	}

	public void setCancelTimeEnd(String cancelTimeEnd) {
		this.cancelTimeEnd = cancelTimeEnd;
	}

	public String getCancelTimeBeginHHmmss() {
		return cancelTimeBeginHHmmss;
	}

	public void setCancelTimeBeginHHmmss(String cancelTimeBeginHHmmss) {
		this.cancelTimeBeginHHmmss = cancelTimeBeginHHmmss;
	}

	public String getCancelTimeEndHHmmss() {
		return cancelTimeEndHHmmss;
	}

	public void setCancelTimeEndHHmmss(String cancelTimeEndHHmmss) {
		this.cancelTimeEndHHmmss = cancelTimeEndHHmmss;
	}

	public String getSku() {
		return sku;
	}

	public void setSku(String sku) {
		this.sku = sku;
	}

	public List<String> getSkuList() {
		return skuList;
	}

	public void setSkuList(List<String> skuList) {
		this.skuList = skuList;
	}

	public List<String> getSkuListNotIn() {
		return skuListNotIn;
	}

	public void setSkuListNotIn(List<String> skuListNotIn) {
		this.skuListNotIn = skuListNotIn;
	}

	public String getSkuListStr() {
		return skuListStr;
	}

	public void setSkuListStr(String skuListStr) {
		this.skuListStr = skuListStr;
	}

	public String getSkuListNotInStr() {
		return skuListNotInStr;
	}

	public void setSkuListNotInStr(String skuListNotInStr) {
		this.skuListNotInStr = skuListNotInStr;
	}

	public String getMemberName() {
		return memberName;
	}

	public void setMemberName(String memberName) {
		this.memberName = memberName;
	}

	public String getMemberPhone() {
		return memberPhone;
	}

	public void setMemberPhone(String memberPhone) {
		this.memberPhone = memberPhone;
	}

	public String getExpectReceiveDateBegin() {
		return expectReceiveDateBegin;
	}

	public void setExpectReceiveDateBegin(String expectReceiveDateBegin) {
		this.expectReceiveDateBegin = expectReceiveDateBegin;
	}

	public String getExpectReceiveDateEnd() {
		return expectReceiveDateEnd;
	}

	public void setExpectReceiveDateEnd(String expectReceiveDateEnd) {
		this.expectReceiveDateEnd = expectReceiveDateEnd;
	}


	public String getPlanedDeliveryDateBegin() {
		return planedDeliveryDateBegin;
	}

	public void setPlanedDeliveryDateBegin(String planedDeliveryDateBegin) {
		this.planedDeliveryDateBegin = planedDeliveryDateBegin;
	}

	

	public String getPlanedDeliveryDateEnd() {
		return planedDeliveryDateEnd;
	}

	public void setPlanedDeliveryDateEnd(String planedDeliveryDateEnd) {
		this.planedDeliveryDateEnd = planedDeliveryDateEnd;
	}

	public String getReceiver() {
		return receiver;
	}

	public void setReceiver(String receiver) {
		this.receiver = receiver;
	}

	public String getReceiverPhone() {
		return receiverPhone;
	}

	public void setReceiverPhone(String receiverPhone) {
		this.receiverPhone = receiverPhone;
	}

	public String getDeliveryCode() {
		return deliveryCode;
	}

	public void setDeliveryCode(String deliveryCode) {
		this.deliveryCode = deliveryCode;
	}

	public String getExpressType() {
		return expressType;
	}

	public void setExpressType(String expressType) {
		this.expressType = expressType;
	}

	public List<String> getExpressTypeList() {
		return expressTypeList;
	}

	public void setExpressTypeList(List<String> expressTypeList) {
		this.expressTypeList = expressTypeList;
	}

	public String getExpressTypeListStr() {
		return expressTypeListStr;
	}

	public void setExpressTypeListStr(String expressTypeListStr) {
		this.expressTypeListStr = expressTypeListStr;
	}

	public long getProvinceId() {
		return provinceId;
	}

	public void setProvinceId(long provinceId) {
		this.provinceId = provinceId;
	}

	public List<Long> getProvinceIdList() {
		return provinceIdList;
	}

	public void setProvinceIdList(List<Long> provinceIdList) {
		this.provinceIdList = provinceIdList;
	}

	public List<Long> getCityIdList() {
		return cityIdList;
	}

	public void setCityIdList(List<Long> cityIdList) {
		this.cityIdList = cityIdList;
	}

	public Integer getPackageStatus() {
		return packageStatus;
	}

	public void setPackageStatus(Integer packageStatus) {
		this.packageStatus = packageStatus;
	}

	public String getAddress() {
		return address;
	}

	public void setAddress(String address) {
		this.address = address;
	}

	public List<Long> getDistrictIdList() {
		return districtIdList;
	}

	public void setDistrictIdList(List<Long> districtIdList) {
		this.districtIdList = districtIdList;
	}

	public List<String> getChannelCodeList() {
		return channelCodeList;
	}

	public void setChannelCodeList(List<String> channelCodeList) {
		this.channelCodeList = channelCodeList;
	}

	public List<Integer> getSalesOrderTypeList() {
		return salesOrderTypeList;
	}

	public void setSalesOrderTypeList(List<Integer> salesOrderTypeList) {
		this.salesOrderTypeList = salesOrderTypeList;
	}

	public String getChannelCodeListStr() {
		return channelCodeListStr;
	}

	public void setChannelCodeListStr(String channelCodeListStr) {
		this.channelCodeListStr = channelCodeListStr;
	}

	public List<Integer> getPaymentTypeList() {
		return paymentTypeList;
	}

	public void setPaymentTypeList(List<Integer> paymentTypeList) {
		this.paymentTypeList = paymentTypeList;
	}

	public List<Long> getIdList() {return idList;}

	public void setIdList(List<Long> idList) {this.idList = idList;}
	
	public String getGatheringCode() {
		return gatheringCode;
	}

	public void setGatheringCode(String gatheringCode) {
		this.gatheringCode = gatheringCode;
	}

	public Integer getGatheringStatus() {
		return gatheringStatus;
	}

	public void setGatheringStatus(Integer gatheringStatus) {
		this.gatheringStatus = gatheringStatus;
	}

	public String getInvoiceNumber() {
		return invoiceNumber;
	}
	public void setInvoiceNumber(String invoiceNumber) {
		this.invoiceNumber = invoiceNumber;
	}

	public List<Long> getSoIdListNot() {
		return soIdListNot;
	}
	public void setSoIdListNot(List<Long> soIdListNot) {
		this.soIdListNot = soIdListNot;
	}

    public String getPhysicalWarehouseCode() {
        return physicalWarehouseCode;
    }

    public void setPhysicalWarehouseCode(String physicalWarehouseCode) {
        this.physicalWarehouseCode = physicalWarehouseCode;
    }

    public Integer getSkuStatus() {
        return skuStatus;
    }

    public void setSkuStatus(Integer skuStatus) {
        this.skuStatus = skuStatus;
    }
	public Integer getMktGiftReceiveType() {
		return mktGiftReceiveType;
	}
	public void setMktGiftReceiveType(Integer mktGiftReceiveType) {
		this.mktGiftReceiveType = mktGiftReceiveType;
	}
}

==> beast-sales-order-api-2.5.1-20240904.061536-2-sources.jar: com/thebeastshop/salesorder/dto/SoOrderCond.java <==
package com.thebeastshop.salesorder.dto;


import com.thebeastshop.common.BaseQueryCond;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

public class SoOrderCond extends BaseQueryCond {

	// constructor
	public SoOrderCond() {

	}

	// original
	private long id;

	private String code;

	private String outerOrderCode;
	
	private String sourceSoCode;

	private Integer salesOrderType;

	private List<Integer> salesOrderTypeList;

	private Integer salesOrderStatus;

	private List<Integer> salesOrderStatusList;

	private String channelCode;

	private String dispatchChannelCode;

	private String dispatchWarehouseCode;

	private String memberCode;

	private Long createOperatorId;

	private Integer isForceAudit;

	private Integer isDownload;

	private List<Integer> paymentTypeList;

	private BigDecimal needToPayAmount;

	// self
	private List<Long> idList;

	private long userId;

	private Date createTimeBegin;

	private Date createTimeEnd;

	private String createTimeBeginHHmmss;

	private String createTimeEndHHmmss;

	private String payTimeBegin;

	private String payTimeEnd;

	private String payTimeBeginHHmmss;

	private String payTimeEndHHmmss;

	private String cancelTimeBegin;

	private String cancelTimeEnd;

	private String cancelTimeBeginHHmmss;

	private String cancelTimeEndHHmmss;
	private String isProduct;
	private String sku;

	private List<String> skuList;

	private List<String> skuListNotIn;

	private String skuListStr;

	private String skuListNotInStr;

	private String expressType;//快递类型

	private List<String> expressTypeList;//快递类型

	private String expressTypeListStr;//快递类型

	private long provinceId;//包裹配送省份

	private List<Long> provinceIdList; //包裹配送省份列表

	private List<Long> cityIdList; // 包裹配送城市列表

	private String address;//包裹配送详细地址

	private Integer packageStatus;//包裹状态

	private List<Long> districtIdList;//包裹配送区县

	private List<String> channelCodeList;//渠道列表

	private String channelCodeListStr;

	private Integer crossBorderFlag;
	
	private List<Long> soIdListNot;				// 屏蔽的订单id

	/**
	 * 订单人
	 */
	private String memberName;

	/**
	 * 订单人电话
	 */
	private String memberPhone;

	/**
	 * 期望送达日期
	 */
	private String expectReceiveDateBegin;

	private String expectReceiveDateEnd;

	/**
	 * 计划发货日期
	 */
	private String planedDeliveryDateBegin;

	private String planedDeliveryDateEnd;

	/**
	 * 收货人
	 */
	private String receiver;

	/**
	 * 收货人电话
	 */
	private String receiverPhone;

	/**
	 * 快递单号
	 */
	private String deliveryCode;

	/**
	 * 排序
	 */
	private String orderBy;

	/**
	 * 集团合同
	 */
	private String groupContractCode;
    private String createOperatorName;
    
    private String buyerNick;

	private Float minAmount;

	private Float maxAmount;

    private String gatheringCode;			// 收款单号
    private Integer gatheringStatus;		// 收款状态
    private String invoiceNumber;			// 发票号
    private String physicalWarehouseCode; 	// 仓库代码
    private Integer skuStatus; 				// 商品状态

    private Integer mktGiftReceiveType; //领用单类型

	public BigDecimal getNeedToPayAmount() {
		return needToPayAmount;
	}

	public void setNeedToPayAmount(BigDecimal needToPayAmount) {
		this.needToPayAmount = needToPayAmount;
	}

	public Float getMinAmount() {
		return minAmount;
	}

	public void setMinAmount(Float minAmount) {
		this.minAmount = minAmount;
	}

	public Float getMaxAmount() {
		return maxAmount;
	}

	public void setMaxAmount(Float maxAmount) {
		this.maxAmount = maxAmount;
	}

	public String getBuyerNick() {
		return buyerNick;
	}

	public void setBuyerNick(String buyerNick) {
		this.buyerNick = buyerNick;
	}

	public Integer getCrossBorderFlag() {
		return crossBorderFlag;
	}

	public void setCrossBorderFlag(Integer crossBorderFlag) {
		this.crossBorderFlag = crossBorderFlag;
	}
    public String getCreateOperatorName() {
        return createOperatorName;
    }

    public void setCreateOperatorName(String createOperatorName) {
        this.createOperatorName = createOperatorName;
    }

	public String getIsProduct() {
		return isProduct;
	}

	public void setIsProduct(String isProduct) {
		this.isProduct = isProduct;
	}

	public String getGroupContractCode() {
		return groupContractCode;
	}

	public void setGroupContractCode(String groupContractCode) {
		this.groupContractCode = groupContractCode;
	}

	public String getOrderBy() {
		return orderBy;
	}

	public void setOrderBy(String orderBy) {
		this.orderBy = orderBy;
	}

	public long getId() {
		return id;
	}

	public void setId(long id) {
		this.id = id;
	}

	public String getCode() {
		return code;
	}

	public void setCode(String code) {
		this.code = code;
	}

	public String getOuterOrderCode() {
		return outerOrderCode;
	}

	public void setOuterOrderCode(String outerOrderCode) {
		this.outerOrderCode = outerOrderCode;
	}

	public String getSourceSoCode() {
		return sourceSoCode;
	}
	public void setSourceSoCode(String sourceSoCode) {
		this.sourceSoCode = sourceSoCode;
	}

	public Integer getSalesOrderType() {
		return salesOrderType;
	}

	public void setSalesOrderType(Integer salesOrderType) {
		this.salesOrderType = salesOrderType;
	}

	public Integer getSalesOrderStatus() {
		return salesOrderStatus;
	}

	public void setSalesOrderStatus(Integer salesOrderStatus) {
		this.salesOrderStatus = salesOrderStatus;
	}

	public List<Integer> getSalesOrderStatusList() {
		return salesOrderStatusList;
	}

	public void setSalesOrderStatusList(List<Integer> salesOrderStatusList) {
		this.salesOrderStatusList = salesOrderStatusList;
	}

	public String getChannelCode() {
		return channelCode;
	}

	public void setChannelCode(String channelCode) {
		this.channelCode = channelCode;
	}

	public String getDispatchChannelCode() {
		return dispatchChannelCode;
	}

	public void setDispatchChannelCode(String dispatchChannelCode) {
		this.dispatchChannelCode = dispatchChannelCode;
	}

	public String getDispatchWarehouseCode() {
		return dispatchWarehouseCode;
	}

	public void setDispatchWarehouseCode(String dispatchWarehouseCode) {
		this.dispatchWarehouseCode = dispatchWarehouseCode;
	}

	public String getMemberCode() {
		return memberCode;
	}

	public void setMemberCode(String memberCode) {
		this.memberCode = memberCode;
	}

	public Long getCreateOperatorId() {
		return createOperatorId;
	}

	public void setCreateOperatorId(Long createOperatorId) {
		this.createOperatorId = createOperatorId;
	}

	public Integer getIsForceAudit() {
		return isForceAudit;
	}

	public void setIsForceAudit(Integer isForceAudit) {
		this.isForceAudit = isForceAudit;
	}

	public Integer getIsDownload() {
		return isDownload;
	}

	public void setIsDownload(Integer isDownload) {
		this.isDownload = isDownload;
	}

	public long getUserId() {
		return userId;
	}

	public void setUserId(long userId) {
		this.userId = userId;
	}

	public Date getCreateTimeBegin() {
		return createTimeBegin;
	}

	public void setCreateTimeBegin(Date createTimeBegin) {
		this.createTimeBegin = createTimeBegin;
	}

	public Date getCreateTimeEnd() {
		return createTimeEnd;
	}

	public void setCreateTimeEnd(Date createTimeEnd) {
		this.createTimeEnd = createTimeEnd;
	}

	public String getCreateTimeBeginHHmmss() {
		return createTimeBeginHHmmss;
	}

	public void setCreateTimeBeginHHmmss(String createTimeBeginHHmmss) {
		this.createTimeBeginHHmmss = createTimeBeginHHmmss;
	}

	public String getCreateTimeEndHHmmss() {
		return createTimeEndHHmmss;
	}

	public void setCreateTimeEndHHmmss(String createTimeEndHHmmss) {
		this.createTimeEndHHmmss = createTimeEndHHmmss;
	}

	public String getPayTimeBegin() {
		return payTimeBegin;
	}

	public void setPayTimeBegin(String payTimeBegin) {
		this.payTimeBegin = payTimeBegin;
	}

	public String getPayTimeEnd() {
		return payTimeEnd;
	}

	public void setPayTimeEnd(String payTimeEnd) {
		this.payTimeEnd = payTimeEnd;
	}

	public String getPayTimeBeginHHmmss() {
		return payTimeBeginHHmmss;
	}

	public void setPayTimeBeginHHmmss(String payTimeBeginHHmmss) {
		this.payTimeBeginHHmmss = payTimeBeginHHmmss;
	}

	public String getPayTimeEndHHmmss() {
		return payTimeEndHHmmss;
	}

	public void setPayTimeEndHHmmss(String payTimeEndHHmmss) {
		this.payTimeEndHHmmss = payTimeEndHHmmss;
	}

	public String getCancelTimeBegin() {
		return cancelTimeBegin;
	}

	public void setCancelTimeBegin(String cancelTimeBegin) {
		this.cancelTimeBegin = cancelTimeBegin;
	}

	public String getCancelTimeEnd() {
		return cancelTimeEnd;
	}

	public void setCancelTimeEnd(String cancelTimeEnd) {
		this.cancelTimeEnd = cancelTimeEnd;
	}

	public String getCancelTimeBeginHHmmss() {
		return cancelTimeBeginHHmmss;
	}

	public void setCancelTimeBeginHHmmss(String cancelTimeBeginHHmmss) {
		this.cancelTimeBeginHHmmss = cancelTimeBeginHHmmss;
	}

	public String getCancelTimeEndHHmmss() {
		return cancelTimeEndHHmmss;
	}

	public void setCancelTimeEndHHmmss(String cancelTimeEndHHmmss) {
		this.cancelTimeEndHHmmss = cancelTimeEndHHmmss;
	}

	public String getSku() {
		return sku;
	}

	public void setSku(String sku) {
		this.sku = sku;
	}

	public List<String> getSkuList() {
		return skuList;
	}

	public void setSkuList(List<String> skuList) {
		this.skuList = skuList;
	}

	public List<String> getSkuListNotIn() {
		return skuListNotIn;
	}

	public void setSkuListNotIn(List<String> skuListNotIn) {
		this.skuListNotIn = skuListNotIn;
	}

	public String getSkuListStr() {
		return skuListStr;
	}

	public void setSkuListStr(String skuListStr) {
		this.skuListStr = skuListStr;
	}

	public String getSkuListNotInStr() {
		return skuListNotInStr;
	}

	public void setSkuListNotInStr(String skuListNotInStr) {
		this.skuListNotInStr = skuListNotInStr;
	}

	public String getMemberName() {
		return memberName;
	}

	public void setMemberName(String memberName) {
		this.memberName = memberName;
	}

	public String getMemberPhone() {
		return memberPhone;
	}

	public void setMemberPhone(String memberPhone) {
		this.memberPhone = memberPhone;
	}

	public String getExpectReceiveDateBegin() {
		return expectReceiveDateBegin;
	}

	public void setExpectReceiveDateBegin(String expectReceiveDateBegin) {
		this.expectReceiveDateBegin = expectReceiveDateBegin;
	}

	public String getExpectReceiveDateEnd() {
		return expectReceiveDateEnd;
	}

	public void setExpectReceiveDateEnd(String expectReceiveDateEnd) {
		this.expectReceiveDateEnd = expectReceiveDateEnd;
	}


	public String getPlanedDeliveryDateBegin() {
		return planedDeliveryDateBegin;
	}

	public void setPlanedDeliveryDateBegin(String planedDeliveryDateBegin) {
		this.planedDeliveryDateBegin = planedDeliveryDateBegin;
	}

	

	public String getPlanedDeliveryDateEnd() {
		return planedDeliveryDateEnd;
	}

	public void setPlanedDeliveryDateEnd(String planedDeliveryDateEnd) {
		this.planedDeliveryDateEnd = planedDeliveryDateEnd;
	}

	public String getReceiver() {
		return receiver;
	}

	public void setReceiver(String receiver) {
		this.receiver = receiver;
	}

	public String getReceiverPhone() {
		return receiverPhone;
	}

	public void setReceiverPhone(String receiverPhone) {
		this.receiverPhone = receiverPhone;
	}

	public String getDeliveryCode() {
		return deliveryCode;
	}

	public void setDeliveryCode(String deliveryCode) {
		this.deliveryCode = deliveryCode;
	}

	public String getExpressType() {
		return expressType;
	}

	public void setExpressType(String expressType) {
		this.expressType = expressType;
	}

	public List<String> getExpressTypeList() {
		return expressTypeList;
	}

	public void setExpressTypeList(List<String> expressTypeList) {
		this.expressTypeList = expressTypeList;
	}

	public String getExpressTypeListStr() {
		return expressTypeListStr;
	}

	public void setExpressTypeListStr(String expressTypeListStr) {
		this.expressTypeListStr = expressTypeListStr;
	}

	public long getProvinceId() {
		return provinceId;
	}

	public void setProvinceId(long provinceId) {
		this.provinceId = provinceId;
	}

	public List<Long> getProvinceIdList() {
		return provinceIdList;
	}

	public void setProvinceIdList(List<Long> provinceIdList) {
		this.provinceIdList = provinceIdList;
	}

	public List<Long> getCityIdList() {
		return cityIdList;
	}

	public void setCityIdList(List<Long> cityIdList) {
		this.cityIdList = cityIdList;
	}

	public Integer getPackageStatus() {
		return packageStatus;
	}

	public void setPackageStatus(Integer packageStatus) {
		this.packageStatus = packageStatus;
	}

	public String getAddress() {
		return address;
	}

	public void setAddress(String address) {
		this.address = address;
	}

	public List<Long> getDistrictIdList() {
		return districtIdList;
	}

	public void setDistrictIdList(List<Long> districtIdList) {
		this.districtIdList = districtIdList;
	}

	public List<String> getChannelCodeList() {
		return channelCodeList;
	}

	public void setChannelCodeList(List<String> channelCodeList) {
		this.channelCodeList = channelCodeList;
	}

	public List<Integer> getSalesOrderTypeList() {
		return salesOrderTypeList;
	}

	public void setSalesOrderTypeList(List<Integer> salesOrderTypeList) {
		this.salesOrderTypeList = salesOrderTypeList;
	}

	public String getChannelCodeListStr() {
		return channelCodeListStr;
	}

	public void setChannelCodeListStr(String channelCodeListStr) {
		this.channelCodeListStr = channelCodeListStr;
	}

	public List<Integer> getPaymentTypeList() {
		return paymentTypeList;
	}

	public void setPaymentTypeList(List<Integer> paymentTypeList) {
		this.paymentTypeList = paymentTypeList;
	}

	public List<Long> getIdList() {return idList;}

	public void setIdList(List<Long> idList) {this.idList = idList;}
	
	public String getGatheringCode() {
		return gatheringCode;
	}

	public void setGatheringCode(String gatheringCode) {
		this.gatheringCode = gatheringCode;
	}

	public Integer getGatheringStatus() {
		return gatheringStatus;
	}

	public void setGatheringStatus(Integer gatheringStatus) {
		this.gatheringStatus = gatheringStatus;
	}

	public String getInvoiceNumber() {
		return invoiceNumber;
	}
	public void setInvoiceNumber(String invoiceNumber) {
		this.invoiceNumber = invoiceNumber;
	}

	public List<Long> getSoIdListNot() {
		return soIdListNot;
	}
	public void setSoIdListNot(List<Long> soIdListNot) {
		this.soIdListNot = soIdListNot;
	}

    public String getPhysicalWarehouseCode() {
        return physicalWarehouseCode;
    }

    public void setPhysicalWarehouseCode(String physicalWarehouseCode) {
        this.physicalWarehouseCode = physicalWarehouseCode;
    }

    public Integer getSkuStatus() {
        return skuStatus;
    }

    public void setSkuStatus(Integer skuStatus) {
        this.skuStatus = skuStatus;
    }
	public Integer getMktGiftReceiveType() {
		return mktGiftReceiveType;
	}
	public void setMktGiftReceiveType(Integer mktGiftReceiveType) {
		this.mktGiftReceiveType = mktGiftReceiveType;
	}
}
